==> redisson-3.22.0-sources.jar: org/redisson/client/handler/PubSubKey.java <==
/**
 * Copyright (c) 2013-2022 Nikita Koksharov
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.redisson.client.handler;

import org.redisson.client.ChannelName;

/**
 * 
 * @author Nikita Koksharov
 *
 */
public class PubSubKey {

    private final ChannelName channel;
    private final String operation;
    
    public PubSubKey(ChannelName channel, String operation) {
        super();
        this.channel = channel;
        this.operation = operation;
    }
    
    public ChannelName getChannel() {
        return channel;
    }
    
    public String getOperation() {
        return operation;
    }

    @Override
    @SuppressWarnings("AvoidInlineConditionals")
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((channel == null) ? 0 : channel.hashCode());
        result = prime * result + ((operation == null) ? 0 : operation.hashCode());
        return result;
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj)
            return true;
        if (obj == null)
            return false;
        if (getClass() != obj.getClass())
            return false;
        PubSubKey other = (PubSubKey) obj;
        if (channel == null) {
            if (other.channel != null)
                return false;
        } else if (!channel.equals(other.channel))
            return false;
        if (operation == null) {
            if (other.operation != null)
                return false;
        } else if (!operation.equals(other.operation))
            return false;
        return true;
    }
    
}

==> redisson-3.25.0-sources.jar: org/redisson/client/handler/PubSubKey.java <==
/**
 * Copyright (c) 2013-2022 Nikita Koksharov
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.redisson.client.handler;

import org.redisson.client.ChannelName;

import java.util.Objects;

/**
 * 
 * @author Nikita Koksharov
 *
 */
public class PubSubKey {

    private final ChannelName channel;
    private final String operation;
    
    public PubSubKey(ChannelName channel, String operation) {
        super();
        this.channel = channel;
        this.operation = operation;
    }
    
    public ChannelName getChannel() {
        return channel;
    }
    
    public String getOperation() {
        return operation;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        PubSubKey pubSubKey = (PubSubKey) o;
        return Objects.equals(channel, pubSubKey.channel) && Objects.equals(operation, pubSubKey.operation);
    }

    @Override
    public int hashCode() {
        return Objects.hash(channel, operation);
    }
}
